require 'net/http'
require 'json'

class GemanticScholar
end

class GemanticScholar::Paper
  attr_accessor :paper_data
  def initialize(paper_id, id_type)
    @paper_data = JSON.parse(fetch_paper(paper_id, id_type))
  end

  def abstract
    paper_data['abstract']
  end

  def arxiv_id
    paper_data['arxivId']
  end

  def authors
    paper_data['authors']
  end

  def citations
    paper_data['citations']
  end

  def doi
    paper_data['doi']
  end

  def references
    paper_data['references']
  end

  def works_cited
    self.references
  end

  def title
    paper_data['title']
  end

  def intent
    paper_data['intent']
  end

  def topics
    paper_data['topics']
  end

  def year
    paper_data['year']
  end

  def publisher
    paper_data['venue']
  end

  def semscholar_id
    paper_data['paperId']
  end

  def venue
    self.publisher
  end

  def fetch_paper(paper_id, id_type)
    if id_type == 'arxiv'
      id_param = "arXiv:#{paper_id}"
    elsif id_type == 'mag'
      id_param = "MAG:#{paper_id}"
    elsif id_type == 'acl'
      id_param = "ACL:#{paper_id}"
    elsif id_type == 'pubmed'
      id_param = "PMID:#{paper_id}"
    elsif id_type == 'corpus'
      id_param = "CorpusID:#{paper_id}"
    else
      id_param = paper_id
    end
    uri = URI("https://api.semanticscholar.org/v1/paper/#{id_param}?include_unknown_references=true")
    rsp = Net::HTTP.get_response(uri)
    if rsp.code == '404'
      return '["404: No paper found"]'
    else
      return rsp.body
    end
  end
end
